
Generate pauliRGB for FP data (``pauliRGB``)
--------------------------------------------

.. autofunction:: polsartools.pauliRGB
   :noindex:


Generate false color RGB for DP/CP data (``dxpRGB``)
----------------------------------------------------

.. autofunction:: polsartools.dxpRGB
   :noindex:

Generate false color RGB for decomposed powers (``rgb``)
--------------------------------------------------------

.. autofunction:: polsartools.rgb
   :noindex:


Generate polarimetric signatures for FP data (``fp_sign``)
----------------------------------------------------------

.. autofunction:: polsartools.fp_sign
   :noindex:
